<html>
    <head>
        <title>Teste</title>
        <script type="text/javascript" src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js"></script>
        {{ form.media }}
    </head>
    <body>
        <form>
            {{ form.as_p }}
            <input type="submit" />
        </form>
    </body>
</html>